==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_athena/paginator.py <==
"""
Type annotations for athena service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_athena.client import AthenaClient
    from types_boto3_athena.paginator import (
        GetQueryResultsPaginator,
        ListDataCatalogsPaginator,
        ListDatabasesPaginator,
        ListNamedQueriesPaginator,
        ListQueryExecutionsPaginator,
        ListTableMetadataPaginator,
        ListTagsForResourcePaginator,
    )

    session = Session()
    client: AthenaClient = session.client("athena")

    get_query_results_paginator: GetQueryResultsPaginator = client.get_paginator("get_query_results")
    list_data_catalogs_paginator: ListDataCatalogsPaginator = client.get_paginator("list_data_catalogs")
    list_databases_paginator: ListDatabasesPaginator = client.get_paginator("list_databases")
    list_named_queries_paginator: ListNamedQueriesPaginator = client.get_paginator("list_named_queries")
    list_query_executions_paginator: ListQueryExecutionsPaginator = client.get_paginator("list_query_executions")
    list_table_metadata_paginator: ListTableMetadataPaginator = client.get_paginator("list_table_metadata")
    list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    GetQueryResultsInputGetQueryResultsPaginateTypeDef,
    GetQueryResultsOutputTypeDef,
    ListDatabasesInputListDatabasesPaginateTypeDef,
    ListDatabasesOutputTypeDef,
    ListDataCatalogsInputListDataCatalogsPaginateTypeDef,
    ListDataCatalogsOutputTypeDef,
    ListNamedQueriesInputListNamedQueriesPaginateTypeDef,
    ListNamedQueriesOutputTypeDef,
    ListQueryExecutionsInputListQueryExecutionsPaginateTypeDef,
    ListQueryExecutionsOutputTypeDef,
    ListTableMetadataInputListTableMetadataPaginateTypeDef,
    ListTableMetadataOutputTypeDef,
    ListTagsForResourceInputListTagsForResourcePaginateTypeDef,
    ListTagsForResourceOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "GetQueryResultsPaginator",
    "ListDataCatalogsPaginator",
    "ListDatabasesPaginator",
    "ListNamedQueriesPaginator",
    "ListQueryExecutionsPaginator",
    "ListTableMetadataPaginator",
    "ListTagsForResourcePaginator",
)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class GetQueryResultsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/GetQueryResults.html#Athena.Paginator.GetQueryResults)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#getqueryresultspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[GetQueryResultsInputGetQueryResultsPaginateTypeDef]
    ) -> _PageIterator[GetQueryResultsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/GetQueryResults.html#Athena.Paginator.GetQueryResults.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#getqueryresultspaginator)
        """


class ListDataCatalogsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListDataCatalogs.html#Athena.Paginator.ListDataCatalogs)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listdatacatalogspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListDataCatalogsInputListDataCatalogsPaginateTypeDef]
    ) -> _PageIterator[ListDataCatalogsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListDataCatalogs.html#Athena.Paginator.ListDataCatalogs.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listdatacatalogspaginator)
        """


class ListDatabasesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListDatabases.html#Athena.Paginator.ListDatabases)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listdatabasespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListDatabasesInputListDatabasesPaginateTypeDef]
    ) -> _PageIterator[ListDatabasesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListDatabases.html#Athena.Paginator.ListDatabases.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listdatabasespaginator)
        """


class ListNamedQueriesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListNamedQueries.html#Athena.Paginator.ListNamedQueries)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listnamedqueriespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListNamedQueriesInputListNamedQueriesPaginateTypeDef]
    ) -> _PageIterator[ListNamedQueriesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListNamedQueries.html#Athena.Paginator.ListNamedQueries.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listnamedqueriespaginator)
        """


class ListQueryExecutionsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListQueryExecutions.html#Athena.Paginator.ListQueryExecutions)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listqueryexecutionspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListQueryExecutionsInputListQueryExecutionsPaginateTypeDef]
    ) -> _PageIterator[ListQueryExecutionsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListQueryExecutions.html#Athena.Paginator.ListQueryExecutions.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listqueryexecutionspaginator)
        """


class ListTableMetadataPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListTableMetadata.html#Athena.Paginator.ListTableMetadata)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listtablemetadatapaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListTableMetadataInputListTableMetadataPaginateTypeDef]
    ) -> _PageIterator[ListTableMetadataOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListTableMetadata.html#Athena.Paginator.ListTableMetadata.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listtablemetadatapaginator)
        """


class ListTagsForResourcePaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListTagsForResource.html#Athena.Paginator.ListTagsForResource)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listtagsforresourcepaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListTagsForResourceInputListTagsForResourcePaginateTypeDef]
    ) -> _PageIterator[ListTagsForResourceOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListTagsForResource.html#Athena.Paginator.ListTagsForResource.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listtagsforresourcepaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_athena/paginator.py <==
"""
Type annotations for athena service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_athena.client import AthenaClient
    from types_boto3_athena.paginator import (
        GetQueryResultsPaginator,
        ListDataCatalogsPaginator,
        ListDatabasesPaginator,
        ListNamedQueriesPaginator,
        ListQueryExecutionsPaginator,
        ListTableMetadataPaginator,
        ListTagsForResourcePaginator,
    )

    session = Session()
    client: AthenaClient = session.client("athena")

    get_query_results_paginator: GetQueryResultsPaginator = client.get_paginator("get_query_results")
    list_data_catalogs_paginator: ListDataCatalogsPaginator = client.get_paginator("list_data_catalogs")
    list_databases_paginator: ListDatabasesPaginator = client.get_paginator("list_databases")
    list_named_queries_paginator: ListNamedQueriesPaginator = client.get_paginator("list_named_queries")
    list_query_executions_paginator: ListQueryExecutionsPaginator = client.get_paginator("list_query_executions")
    list_table_metadata_paginator: ListTableMetadataPaginator = client.get_paginator("list_table_metadata")
    list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    GetQueryResultsInputPaginateTypeDef,
    GetQueryResultsOutputTypeDef,
    ListDatabasesInputPaginateTypeDef,
    ListDatabasesOutputTypeDef,
    ListDataCatalogsInputPaginateTypeDef,
    ListDataCatalogsOutputTypeDef,
    ListNamedQueriesInputPaginateTypeDef,
    ListNamedQueriesOutputTypeDef,
    ListQueryExecutionsInputPaginateTypeDef,
    ListQueryExecutionsOutputTypeDef,
    ListTableMetadataInputPaginateTypeDef,
    ListTableMetadataOutputTypeDef,
    ListTagsForResourceInputPaginateTypeDef,
    ListTagsForResourceOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "GetQueryResultsPaginator",
    "ListDataCatalogsPaginator",
    "ListDatabasesPaginator",
    "ListNamedQueriesPaginator",
    "ListQueryExecutionsPaginator",
    "ListTableMetadataPaginator",
    "ListTagsForResourcePaginator",
)


if TYPE_CHECKING:
    _GetQueryResultsPaginatorBase = Paginator[GetQueryResultsOutputTypeDef]
else:
    _GetQueryResultsPaginatorBase = Paginator  # type: ignore[assignment]


class GetQueryResultsPaginator(_GetQueryResultsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/GetQueryResults.html#Athena.Paginator.GetQueryResults)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#getqueryresultspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[GetQueryResultsInputPaginateTypeDef]
    ) -> PageIterator[GetQueryResultsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/GetQueryResults.html#Athena.Paginator.GetQueryResults.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#getqueryresultspaginator)
        """


if TYPE_CHECKING:
    _ListDataCatalogsPaginatorBase = Paginator[ListDataCatalogsOutputTypeDef]
else:
    _ListDataCatalogsPaginatorBase = Paginator  # type: ignore[assignment]


class ListDataCatalogsPaginator(_ListDataCatalogsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListDataCatalogs.html#Athena.Paginator.ListDataCatalogs)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listdatacatalogspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListDataCatalogsInputPaginateTypeDef]
    ) -> PageIterator[ListDataCatalogsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListDataCatalogs.html#Athena.Paginator.ListDataCatalogs.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listdatacatalogspaginator)
        """


if TYPE_CHECKING:
    _ListDatabasesPaginatorBase = Paginator[ListDatabasesOutputTypeDef]
else:
    _ListDatabasesPaginatorBase = Paginator  # type: ignore[assignment]


class ListDatabasesPaginator(_ListDatabasesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListDatabases.html#Athena.Paginator.ListDatabases)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listdatabasespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListDatabasesInputPaginateTypeDef]
    ) -> PageIterator[ListDatabasesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListDatabases.html#Athena.Paginator.ListDatabases.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listdatabasespaginator)
        """


if TYPE_CHECKING:
    _ListNamedQueriesPaginatorBase = Paginator[ListNamedQueriesOutputTypeDef]
else:
    _ListNamedQueriesPaginatorBase = Paginator  # type: ignore[assignment]


class ListNamedQueriesPaginator(_ListNamedQueriesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListNamedQueries.html#Athena.Paginator.ListNamedQueries)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listnamedqueriespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListNamedQueriesInputPaginateTypeDef]
    ) -> PageIterator[ListNamedQueriesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListNamedQueries.html#Athena.Paginator.ListNamedQueries.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listnamedqueriespaginator)
        """


if TYPE_CHECKING:
    _ListQueryExecutionsPaginatorBase = Paginator[ListQueryExecutionsOutputTypeDef]
else:
    _ListQueryExecutionsPaginatorBase = Paginator  # type: ignore[assignment]


class ListQueryExecutionsPaginator(_ListQueryExecutionsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListQueryExecutions.html#Athena.Paginator.ListQueryExecutions)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listqueryexecutionspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListQueryExecutionsInputPaginateTypeDef]
    ) -> PageIterator[ListQueryExecutionsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListQueryExecutions.html#Athena.Paginator.ListQueryExecutions.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listqueryexecutionspaginator)
        """


if TYPE_CHECKING:
    _ListTableMetadataPaginatorBase = Paginator[ListTableMetadataOutputTypeDef]
else:
    _ListTableMetadataPaginatorBase = Paginator  # type: ignore[assignment]


class ListTableMetadataPaginator(_ListTableMetadataPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListTableMetadata.html#Athena.Paginator.ListTableMetadata)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listtablemetadatapaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListTableMetadataInputPaginateTypeDef]
    ) -> PageIterator[ListTableMetadataOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListTableMetadata.html#Athena.Paginator.ListTableMetadata.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listtablemetadatapaginator)
        """


if TYPE_CHECKING:
    _ListTagsForResourcePaginatorBase = Paginator[ListTagsForResourceOutputTypeDef]
else:
    _ListTagsForResourcePaginatorBase = Paginator  # type: ignore[assignment]


class ListTagsForResourcePaginator(_ListTagsForResourcePaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListTagsForResource.html#Athena.Paginator.ListTagsForResource)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listtagsforresourcepaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListTagsForResourceInputPaginateTypeDef]
    ) -> PageIterator[ListTagsForResourceOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena/paginator/ListTagsForResource.html#Athena.Paginator.ListTagsForResource.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_athena/paginators/#listtagsforresourcepaginator)
        """
